function [L2,Ptilde,PP, PX, PY, X,Y,BX,BY]=CA_largematrix(P,r,c,k)

% this program performs CA.
% input can be any nonnegative matrix. (Indicator, or contingency matrix)
% dimensionaliaty of solution is k.
%
% Implementation that deals a bit better with large matrices
% INPUT 
%
%  P       correspondence matrix P = (1/n) * N;
%  r       row masses r  = P * Ic ;
%  c       column masses; Centroid of the row profiles   r' * Dr^(-1) * P = 1' * P = c'
%          c  = (Ir' * P)';
% OUTPUT
%
% L2        First k eigenvalues
% Ptilde    Standarized residuals
% PP        A'*A (to compute total inertia)
% PX        Principal coordinates of rows
% PY        Principal coordinates of columns
% X         Standard coordinates of rows
% Y         Standard coordinates of columns
% BX        Symmetrical coordinates of rows
% BY        Symmetrical coordinates of columns
%
    [n,p]=size(P);

    ri=r.^-0.5;
    ci=c.^-0.5;
    Pdev=P-r*c';
    Ptilde=[];
    Ptilde=zeros(n,p);
    % To avoid calculations with huge diagonal matrices:
    for i=1:n,
        Ptilde(i,:)=Pdev(i,:).*ri(i);
    end
    for j=1:p,
        Ptilde(:,j)=Ptilde(:,j).*ci(j);
    end
    
    PP=Ptilde'*Ptilde;
    [V,L2]=eigs(PP, k); % Use eigs for speed (only K largest eigenvalues are
                        % obtained. For relative inertia calculations trace
                        % of PP can be used.
                       
    L=L2^.5;            % The eigenvalues of PP are the squares of the singular
                        % values that we need in the calculations of
                        % principal coordinates etc.
   
    U=Ptilde*V*inv(L);  % Orthonormal vector needed for row coordinates.
                        % V is already the vector for the columns
                        % L provides the singular values
   

% standard coordinates:
    
    %rows
    X=zeros(n,k);
    for i=1:n,
        X(i,:)=U(i,:).*ri(i);
    end
    %columns
    Y=zeros(p,k);
    for j=1:p,
        Y(j,:)=V(j,:).*ci(j);
    end

% principal coordinates:
   
    %rows
    PX=X*L;
    %columns
    PY=Y*L;

% Symmetrical coordinates: (lambda 0.5)

     %rows
     BX=X*L^0.5;
     %columns
     BY=Y*L^0.5;
     %BXk=BX(:,1:k);
     %BYk=BY(:,1:k);
