function output_new = ComputeInertias( output, maxk  )

output_new = output;

A=output.A;
K=output.K;
n = output.n;
I=output.I;
J=output.J;
Ir = ones(I,1);
Ic = ones(J,1);

[V,L2]=my_eigs(A'*A, maxk); 
L=L2^.5;
U=A*V*inv(L);  % Orthonormal vector needed for row coordinates.

% Principal inertias 
% 
% eigenvalues of A'A
% percentages of the total inertia 

ti=output.ti;

api = [];tmp=0;
for i=1:maxk,
    tmp = tmp + L(i,i)*L(i,i)/ti;
    api = [api; tmp];
end;
LL=diag(L.*L);
LL = LL(1:maxk);
output_new.eig = [LL (LL / ti) api] ;      % Principal inertias [Raw Percentage Acumulate_percentage]

output_new.aev = 100/maxk;                        %Average explained variance (dimensions explaining less variance should be excluded from the map)

Dr=output.Dr;
Dc=output.Dc;

F = Dr^(-1/2) * U*L;
G = Dc^(-1/2) * V*L;                        
X = Dr^(-1/2) * U ;
Y = Dc^(-1/2) * V ;
H = Dr^(-1/2) * U*L^(1/2);
Z = Dc^(-1/2) * V*L^(1/2);
k = output.k;

% Contributions of rows to inertia 
% 
ARC = Dr*X.*X;
output_new.ARC = ARC;                          % Absolute row contributions: Contributions of points to axes.

% Contributions of columns to inertia
% 
ACC = Dc*Y.*Y;
output_new.ACC = ACC;                          % Absolute column contributions: Contributions of points to axes.

%Inertia of each row
%
INr = Dr*(F.*F)*ones(maxk,1);

%Inertia relative to their total (used in the output)
%INr_p=INr / trace(L.*L);
INr_p=INr / ti;
output_new.INr = [INr INr_p];                   %Inertia of each row [raw percentage]

%Inertia of each column
%
INc = Dc*(G.*G)*ones(maxk,1);

%Inertia relative to their total (used in the output)
%INc_p=INc / trace(L.*L);
INc_p=INc / ti;
output_new.INc = [INc INc_p];                   %Inertia of each column [raw percentage]

%Squared correlations of rows with axes
%
QCOR_r = diag(INr)^(-1)*Dr*(F.*F);
output_new.RRC=QCOR_r;                          %Relative row contributions: Contributions of axes to points; squared correlations of points with axes

%Squared correlations of columns with axes
%
QCOR_c = diag(INc)^(-1)*Dc*(G.*G);
output_new.RCC=QCOR_c;                          %Relative columns contributions: Contributions of axes to points; squared correlations of points with axes

%Measure of quality of display for each row in the reduced k-dimensional map. The qualities are equivalent to the communalities in PCA 
%
QLTr = QCOR_r(:,1:k)*ones(k,1);
output_new.QLTr = QLTr;                         %Measure of quality of display for each row in the reduced k-dimensional map. The qualities are equivalent to the communalities in PCA 

%Measure of quality of display for each column in the reduced k-dimensional map. The qualities are equivalent to the communalities in PCA 
%
QLTc = QCOR_c(:,1:k)*ones(k,1);
output_new.QLTc = QLTc;                         %Measure of quality of display for each column in the reduced k-dimensional map. The qualities are equivalent to the communalities in PCA 

%Correlation of rows with axes. Similar to component loadings in PCA
%
Br = sign(F).*sqrt(QCOR_r);
output_new.Br = Br;                             %Correlation of rows with axes. Similar to component loadings in PCA

%Correlation of columns with axes. Similar to component loadings in PCA
%
Bc = sign(G).*sqrt(QCOR_c);
output_new.Bc = Bc;                             %Correlation of columns with axes. Similar to component loadings in PCA

output_new.F = F;                               % Principal coordinates of rows
output_new.G = G;                               % Principal coordinates of columns
output_new.X = X;                               % Standard coordinates of rows
output_new.Y = Y;                               % Standard coordinates of columns
output_new.H = H;                               % Symmetrical coordinates of rows
output_new.Z=Z;                                 % Symmetrical coordinates of columns

end

